@@ -13,7 +13,7 @@ class ServiceOnlyBootstrap(Bootstrap):
         set(Bootstrap.recipe_depends).union({'genericndkbuild'})
     )
 
-    def run_distribute(self):
+    def assemble_distribution(self):
         info_main('# Creating Android project from build and {} bootstrap'.format(
             self.name))
 
@@ -46,10 +46,10 @@ class ServiceOnlyBootstrap(Bootstrap):
                 with open('blacklist.txt', 'a') as fileh:
                     fileh.write('\nsqlite3/*\nlib-dynload/_sqlite3.so\n')
 
-        if not self.ctx.build_as_debuggable:
+        if not self.ctx.with_debug_symbols:
             self.strip_libraries(arch)
         self.fry_eggs(site_packages_dir)
-        super().run_distribute()
+        super().assemble_distribution()
 
 
 bootstrap = ServiceOnlyBootstrap()
