@@ -447,6 +447,9 @@ class Context:
         self.local_recipes = None
         self.copy_libs = False
 
+        self.activity_class_name = u'org.kivy.android.PythonActivity'
+        self.service_class_name = u'org.kivy.android.PythonService'
+
         # this list should contain all Archs, it is pruned later
         self.archs = (
             ArchARM(self),
