@@ -8,15 +8,15 @@ class PandasRecipe(CppCompiledComponentsPythonRecipe):
     url = 'https://github.com/pandas-dev/pandas/releases/download/v{version}/pandas-{version}.tar.gz'  # noqa
 
     depends = ['cython', 'numpy', 'pytz', 'libbz2', 'liblzma']
-    conflicts = ['python2']
 
     python_depends = ['python-dateutil']
     patches = ['fix_numpy_includes.patch']
 
     call_hostpython_via_targetpython = False
+    need_stl_shared = True
 
     def get_recipe_env(self, arch):
-        env = super(PandasRecipe, self).get_recipe_env(arch)
+        env = super().get_recipe_env(arch)
         # we need the includes from our installed numpy at site packages
         # because we need some includes generated at numpy's compile time
         env['NUMPY_INCLUDES'] = join(
@@ -28,7 +28,7 @@ class PandasRecipe(CppCompiledComponentsPythonRecipe):
         #   "_ZTVSt12length_error" referenced by
         #   "/data/data/org.test.matplotlib_testapp/files/app/_python_bundle
         #   /site-packages/pandas/_libs/window/aggregations.so"...
-        env['LDFLAGS'] += ' -landroid'
+        env['LDFLAGS'] += f' -landroid  -l{self.stl_lib_name}'
         return env
 
 
