@@ -10,7 +10,7 @@ class PyICURecipe(CppCompiledComponentsPythonRecipe):
     patches = ['locale.patch']
 
     def get_recipe_env(self, arch):
-        env = super(PyICURecipe, self).get_recipe_env(arch)
+        env = super().get_recipe_env(arch)
 
         icu_include = join(
             self.ctx.get_python_install_dir(), "include", "icu")
