@@ -20,7 +20,7 @@ class ZBarRecipe(PythonRecipe):
     patches = ["zbar-0.10-python-crash.patch"]
 
     def get_recipe_env(self, arch=None, with_flags_in_cc=True):
-        env = super(ZBarRecipe, self).get_recipe_env(arch, with_flags_in_cc)
+        env = super().get_recipe_env(arch, with_flags_in_cc)
         libzbar = self.get_recipe('libzbar', self.ctx)
         libzbar_dir = libzbar.get_build_dir(arch.arch)
         env['PYTHON_ROOT'] = self.ctx.get_python_install_dir()
